@@ -11,6 +11,7 @@ my $user;
 my $server;
 my $port;
 my $ircname;
+my $password;
 my $current_channel;
 
 GetOptions(
@@ -18,13 +19,14 @@ GetOptions(
 "server=s" => \$server,
 "user=s" => \$user,
 "port=s" => \$port,
+"pass=s" => \$password,
 "ircname=s" => \$ircname,
 );
 
 die unless $nick and $server;
 print "$nick $server\n";
 
-my $irc = POE::Component::IRC::State->spawn( Nick => $nick, Server => $server, Port => $port, Ircname => $ircname, Username => $user );
+my $irc = POE::Component::IRC::State->spawn( Nick => $nick, Server => $server, Port => $port, Ircname => $ircname, Username => $user, Password => $password );
 
 POE::Session->create(
 	package_states => [
